@@ -1,5 +1,6 @@
 #!/usr/bin/python3.6
-from . import connector
+# from . import connector
+from site24x7_plugin_helper.connector.database_client import DatabaseClient
 import sys
 import os
 import json
@@ -11,7 +12,6 @@ from subprocess import call
 # handler = logging.FileHandler('/tmp/plugin.log')
 # logger.info(msg="test")
 # breakpoint()
-#import ggplot as gg
 passDbConnection = True
 
 
@@ -34,11 +34,12 @@ if __name__ == "__main__":
         "thisPluginName":thisPluginName,
     }
     if not passDbConnection:
-        cursor = connector.getCursorFromDatabase(server, database, username, password, driverLocation)
+        DatabaseClient = DatabaseClient(server, database, username, password, driverLocation)
+        cursor = DatabaseClient.cursor
         print("connnected")
         # existing query that returns all rows from the table for caching
         # 'EXEC [Ultramerchant].dbo.pr_membership_credit_billing_stats_24x7_monitor_sel'
-        rows = connector._fetchall(cursor, query)
+        rows = DatabaseClient.fetchall(cursor, query)
         for i in range(len(rows)):
             key = rows[i][1]
             value = rows[i][2]
@@ -48,13 +49,13 @@ if __name__ == "__main__":
     # breakpoint()
     
     # save cache to file as thisPluginName 
-    cacheFileName = "/tmp/" + thisPluginName + ".cache" # 
+    cacheFileName = "/" + thisPluginName + ".cache" # 
     open(cacheFileName, 'w').write(
         json.dumps(cache, indent=4)
     )
     print(json.dumps(cache, indent=4, sort_keys=True))
 
-    site24x7_location = "/opt/site24x7/monagent/plugins//plugin/plugin.py"
+    site24x7_location = "/opt/site24x7/monagent/plugins"
     folderDestination = os.path.join(site24x7_location, thisPluginName)
     fileDestination = os.path.join(folderDestination, thisPluginName + ".py")
     print("folderDestination: " + folderDestination)
@@ -63,14 +64,14 @@ if __name__ == "__main__":
     # create a folder if not exists
     if not os.path.exists(folderDestination):
         call(f"mkdir {folderDestination}", shell=True)
-        os.mkdir(folderDestination)
+        #os.mkdir(folderDestination)
 
     # create a python file if not exists
     if not os.path.isfile(fileDestination):
         call(f"touch {fileDestination}", shell=True)
     open(fileDestination, 'w').write(f'''#!/usr/bin/python3.6
 import json
-from site24x7_plugin_helper.connector import guessMetricByType
+from site24x7_plugin_helper.utils.util import guessMetricByType
 cacheData = json.loads(open("{cacheFileName}").read())
 PLUGIN_VERSION = "2"
 HEARTBEAT = "true"
